@@ -25,8 +25,8 @@
 #include <KCalendarCore/Event>
 #include <KCalendarCore/FileStorage>
 
-#include <Akonadi/Calendar/IncidenceChanger>
 #include <Akonadi/Collection>
+#include <Akonadi/IncidenceChanger>
 
 #include <QElapsedTimer>
 #include <QEventLoop>
@@ -34,8 +34,8 @@
 #include <QTimeZone>
 
 #include <QStandardPaths>
+#include <cstdlib>
 #include <iostream>
-#include <stdlib.h>
 
 using namespace KCalendarCore;
 using namespace std;
@@ -45,9 +45,7 @@ KonsoleKalendarAdd::KonsoleKalendarAdd(KonsoleKalendarVariables *vars)
     m_variables = vars;
 }
 
-KonsoleKalendarAdd::~KonsoleKalendarAdd()
-{
-}
+KonsoleKalendarAdd::~KonsoleKalendarAdd() = default;
 
 /**
  * Adds event to Calendar
